============
Contributers
============

* Kenneth Gade, FFI: Main author of Matlab toolbox nvector.
* Kristian Svartveit, FFI: Contributions to matlab code: R_Ee.m and unit.m.
* Brita Hafskjold Gade, FFI: Contributions to matlab code: n_EB_E2p_EB_E.m, p_EB_E2n_EB_E.m
* Per A Brodtkorb, FFI: Translation of nvector from matlab to Python.

